% loading panel of country monthly data 
% input:  filename: must be a string containing the filename of the data file
%         sheet:    in case of more than 1 xls spread sheet you have to specify it
%         extn:     in case of extensions other than xls, [] for sheet
%         c:        in case you want in the 'base' ws the sample divided by country set c=1
% output: Monthly-data-sample divided by countries in the 'base' ws (set c=1)
%         y: annual sample
%         def: is an index for the annual aggregation method: 0 ,1,2 
%                 if 0 it does not matter
%                 if 1 not strict with n.a.
%                 if 2 strict with n.a.
%         an ascii file in the working directory


function [y, def] = m2y(filename,sheet,extn,c)
global Legd

disp('I Assume data start in January and end in December')

if not(ischar(filename))
    error('filename must be a string')
else
    filename=['''',filename,''''];
end

if nargin==1
    extn='xls';
    x_comm    = [extn,'read'];
    x_to_eval = ['[all_sample, Legd]=',x_comm,'(',filename,');'];
    eval(x_to_eval); 
elseif nargin==2
    extn='xls';
    sheet=['''',sheet,''''];
    x_comm    = [extn,'read'];
    x_to_eval = ['[all_sample, Legd]=',x_comm,'(',filename,',',sheet,');'];
    eval(x_to_eval); 
elseif nargin==3
    x_comm    = [extn,'read'];
    x_to_eval = ['[all_sample, Legd]=',x_comm,'(',filename,');'];
    eval(x_to_eval); 
end

N_mts  = size(all_sample,1);
N_ctry = size(all_sample,2);

% dividing the sample by country (monthly data still)
if c==1
    for i=1:N_ctry
        assignin('base',['country' num2str(i) 'm'],all_sample(:,i)); 
    end
end
% convention: a year of crisis is defined whenever it has at least 1 month of distress      
for i=1:N_mts/12
    % NB I consider n.a. as no crisis events
    indx0 = sum(isnan(all_sample(1+12*(i-1):12*i,:)))<12; % logical array
    indx0=indx0*1; % getting again a numerical
    all_sampleY1(i,:)=any(all_sample(1+12*(i-1):12*i,:))./indx0; 
    % Stricter definition: a n.a. month imply a n.a. year  
    d1    = any(all_sample(1+12*(i-1):12*i,:)); 
    indx1 = intersect((d1).*(1:N_ctry),1:N_ctry);
    indx2 = intersect(not(d1).*(1:N_ctry),1:N_ctry);
    all_sampleY2(i,:)     = ones(1,N_ctry);
    all_sampleY2(i,indx2) = mean(all_sample(1+12*(i-1):12*i,indx2));
end
if isequalwithequalnans(all_sampleY1,all_sampleY2);
    y=all_sampleY1;
    def=0;
else
    diffdef=abs(isnan(all_sampleY1)-isnan(all_sampleY2));
    totdiff=sum(sum(diffdef));
    if totdiff/(N_mts*N_ctry)<.01
        y=all_sampleY1;
        warning('there is at most 1% difference in definitions')
        def=1;
    else
        y=all_sampleY2;
        disp('I use the strict definition')
        def=2;
    end
end

save PSmdata y -ascii
disp(['I save the yearly data!    filename: PSmdata;      path:  ', pwd])


