%%%%% MCMC Sampling from Kernel Density Function %%%%%  

function [XTot] = thresh_est(f1M,xi1M,k1,F,J)

% Starting value set in the peak (highest mode)
[mxx,indx]=sort(f1M);
x=xi1M(indx(end)); accS=0;

D=spline(xi1M,f1M,x);
for i=1:10000
    if x>F
        xnew = x-J+k1*randn;  % left asymmetric
        if xnew>F, 
            N=spline(xi1M,f1M,xnew)*normpdf(x,xnew+J,k1^2)/normpdf(xnew,x-J,k1^2); 
        end
        if xnew<=F, 
            N=spline(xi1M,f1M,xnew)*normpdf(x,xnew,k1^2)/normpdf(xnew,x-J,k1^2); 
        end
    elseif xnew<0
        N=0;
    else
        xnew = x+k1*randn;
        N=spline(xi1M,f1M,xnew);
    end
    
    R=N/D;
    if R>=rand
        X(i)=xnew;
        x=xnew;
        D=N;
        accS=accS+1;
    else
        X(i)=x;
    end
    if i/1500==floor(i/1500), disp(accS/i),end
end

XTot=X;
plot(XTot)
X=X(2500:end);
X((X<=0))=[];


%% Distribution Fitting

[G_est gCI]= gamfit(X);
[W_est wCI] = weibfit(X);

Gp90thL = min([gaminv(.90,gCI(1,1),gCI(1,2)),gaminv(.90,gCI(1,1),gCI(2,2)), ...
        gaminv(.90,gCI(2,1),gCI(1,2)),gaminv(.90,gCI(2,1),gCI(2,2))]);
Gp90thU = max([gaminv(.90,gCI(1,1),gCI(1,2)),gaminv(.90,gCI(1,1),gCI(2,2)), ...
        gaminv(.90,gCI(2,1),gCI(1,2)),gaminv(.90,gCI(2,1),gCI(2,2))]);
Gp90th = [Gp90thL, gaminv(.90,G_est(1),G_est(2)), Gp90thU];

Wp90thL = min([weibinv(.90,wCI(1,1),wCI(1,2)),weibinv(.90,wCI(1,1),wCI(2,2)), ...
        weibinv(.90,wCI(2,1),wCI(1,2)),weibinv(.90,wCI(2,1),wCI(2,2))]);
Wp90thU = max([weibinv(.90,wCI(1,1),wCI(1,2)),weibinv(.90,wCI(1,1),wCI(2,2)), ...
        weibinv(.90,wCI(2,1),wCI(1,2)),weibinv(.90,wCI(2,1),wCI(2,2))]);
Wp90th = [Wp90thL, weibinv(.90,W_est(1),W_est(2)), Wp90thU];

thrG_1000=gamcdf(1000,G_est(1),G_est(2));
thrW_1000=weibcdf(1000,W_est(1),W_est(2));

disp(' ')
disp('|----------------------------------------------------------------------|')
disp('|----------------------------------------------------------------------|')
disp('| ESTIMATED TRHESHOLDS 95% CI, 90th PERCENTILE GAMMA DISTRIBUTION')
fprintf('Lower Bound = %g | Threshold = %g | Upper Bound = %g \n',Gp90th)
disp('|--------')
disp('| ESTIMATED TRHESHOLDS 95% CI, 90th PERCENTILE WEIBUL DISTRIBUTION')
fprintf('Lower Bound = %g | Threshold = %g | Upper Bound = %g \n',Wp90th)
disp('|--------')
disp('| 1000-Threshold and relative percentile')
fprintf(' Gamma percentile = %g |  Weibul percentile = %g \n',[thrG_1000,thrW_1000])
disp('|----------------------------------------------------------------------|')
disp('|----------------------------------------------------------------------|')

